=============================
论世界的本质：组合与结构之美
=============================


世界的本质是组合的系统
=====================

这个世界的本质，是组合，是结构。一切事物都是组合的产物，都是结构的产物。万事万物都在组合中
产生，都在一定的结构中进行演变。一定的组合构成一定的事物，这个事物因为由部分组成，因此可以
叫做一个系统。在以下的论述中，我用系统泛指所有的事物。因为，任何事物，都是一个系统。

系统与系统之间的差异(即事物与事物之间的差异)源于组合的各个部分的差异，或者各个部分如何组合
（组合结构）的差异。

每个系统都拥有一定边界，因为，每个系统都由部分组成，而且由有限的部分组成。不存在无边界的系
统，因为不存在无限部分的组合，当然可能除了组合本身。边界的存在，导致系统的存在。系统的存
在，意味着边界的存在。任何系统都是一个部分，任何部分又都是一个系统。任何一个系统，都是更大
的系统的一个部分；任何一个部分，都是更小部分的一个系统。因此，没有边界，就没有系统，任何系
统都在一定边界内存在。

系统并不是静态的，系统并不是一种状态，系统并不都长久。

组合是所有性质可能的开始
=======================

单个的部分可能并不具备某种性质，但是，当一定数量与一定种类的事物通过一定的组合结构或组合方
式，组合在一起形成系统时，前所未有的性质便可能开始诞生。比如看不见的原子并不具备某种行为，
但是，当大部分原子组合成一个细菌时，细菌便具备迅速繁衍生殖的能力。同样，单个的神经元并不具
备很强的分类能力，但是，当大量的神经元通过奇妙的组成方式，组成一个深度学习网络时，前所未有
的分类性质便由此诞生。而最巧妙的，便是人。人由细胞组成，细胞并不具备智能行为，但是，一定数
量和一定类型的细胞，它们之间通过巧妙的组合方式组合在一起，便形成了如此美妙的、拥有智力的、
具备情感的人。

由此可见，优秀的系统，或由优秀的各个部分组成，或由各个部分优秀的结构组成，或者两者兼备。


组合与结构之美
=====================


这个世界，大量存在着组合与结构之美。

* 文学：什么是优秀的文学？为何莎士比亚的著作如此优美？单个的字词可能并不具备强烈的美感，
  但是，一旦组成句子，句子一旦组成篇章，新的性质便由此诞生，比如故事、哲理。美由此诞生。
* 数据结构：什么样的数据结构，就导致了什么样的执行逻辑。良好的数据结构，导致了高效的程
  序执行。数据结构的美丽，导致了程序的美丽。
* 设计模式：设计模式让相同功能的程序用不同的逻辑结构进行组合，从而产生高效的程序执行与
  良好的代码维护。软件架构之美从这儿起步。
* 深度学习：神经元都是相同的，但是使用不同数量的神经元进行组合，或者使用不同的连接方式
  进行组合，导致了结果的巨大差异。深度学习是结构的艺术，是组合的艺术。

总结
=======

其实，总结起来其实就三句话：

* 所有事物由部分，通过结构，组成。由此，任何事物都是一个系统。
* 由部分组成的系统，可使系统具备部分从未有过的性质，产生出性质的飞跃、与美的飞跃（美
  泛指一切优秀的事物、属性……）。所有新的现象也由此诞生。
* 所有前所未有的、美的现象、性质，都由优秀的部分与优秀的结构，组成。由此提供了方法论。

``2016-11-22``
